**********
mpunittest
**********

A Python library/application for running unittests in parallel and merging results.

Installation
============

To install the latest release from `PyPI <https://pypi.org/project/mpunittest/>`_,
simply run::

    pip install mpunittest

Or to install the latest development version, run::

     git clone https://github.com/maximilianpilz/mpunittest
     python -m pip install .

Quick Start
===========

TODO.

Licensing
=========

Copyright (C) 2023 Maximilian Pilz

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; version 2.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.